@@ -1,6 +1,8 @@
 """Library to access the Smart Device Management API."""
 from typing import List
 
+import aiohttp
+
 from .auth import AbstractAuth
 from .device import Device
 from .structure import Structure
@@ -20,8 +22,7 @@ class GoogleNestAPI:
 
     async def async_get_structures(self) -> List[Structure]:
         """Return the structures."""
-        resp = await self._auth.request("get", self._structures_url)
-        resp.raise_for_status()
+        resp = await self._get(self._structures_url)
         response_data = await resp.json()
         structures = response_data["structures"]
         return [
@@ -30,8 +31,7 @@ class GoogleNestAPI:
 
     async def async_get_structure(self, structure_id) -> Structure:
         """Return a structure device."""
-        resp = await self._auth.request("get", structure_id)
-        resp.raise_for_status()
+        resp = await self._get(structure_id)
         return Structure.MakeStructure(await resp.json())
 
     @property
@@ -40,14 +40,17 @@ class GoogleNestAPI:
 
     async def async_get_devices(self) -> List[Device]:
         """Return the devices."""
-        resp = await self._auth.request("get", self._devices_url)
-        resp.raise_for_status()
+        resp = await self._get(self._devices_url)
         response_data = await resp.json()
         devices = response_data["devices"]
         return [Device.MakeDevice(device_data, self._auth) for device_data in devices]
 
     async def async_get_device(self, device_id) -> Device:
         """Return a specific device."""
-        resp = await self._auth.request("get", device_id)
-        resp.raise_for_status()
+        resp = await self._get(device_id)
         return Device.MakeDevice(await resp.json(), self._auth)
+
+    async def _get(self, url) -> aiohttp.ClientResponse:
+        """Issues an authenticated HTTP get."""
+        resp = await self._auth.request("get", url)
+        return AbstractAuth.raise_for_status(resp)
